plot.glmsmurf: Plot Coefficients of Estimated Model

Description Usage Arguments Details See Also Examples

View source: R/plot.R

Description

Function to plot the coefficients of the estimated model.

Usage

1
2
## S3 method for class 'glmsmurf'
plot(x, xlab = "Index", ylab = "Estimated coefficients", basic = FALSE, ...)

Arguments

x

An object of class 'glmsmurf', typically the result of a call to glmsmurf or glmsmurf.fit.

xlab

Label for the x-axis, default is "Index".

ylab

Label for the y-axis, default is "Estimated coefficients".

basic

Logical indicating if the basic lay-out is used for the plot, default is FALSE.

...

Additional arguments for the plot function.

Details

When basic=FALSE, the improved lay-out for the plot is used. Per predictor, groups of equal coefficients are indicated in the same color (up to 8 colors), and zero coefficients are indicated by grey squares.

See Also

plot_reest, coef.glmsmurf, summary.glmsmurf, glmsmurf, glmsmurf-class

Examples

1
## See example(glmsmurf) for examples

BavoDC/ssmurf documentation built on Dec. 17, 2021, 10:46 a.m.