Description Usage Arguments Details See Also Examples
Function to plot the coefficients of the estimated model.
1 2 |
x |
An object of class ' |
xlab |
Label for the x-axis, default is |
ylab |
Label for the y-axis, default is |
basic |
Logical indicating if the basic lay-out is used for the plot, default is |
... |
Additional arguments for the |
When basic=FALSE, the improved lay-out for the plot is used. Per predictor, groups of equal coefficients are indicated
in the same color (up to 8 colors), and zero coefficients are indicated by grey squares.
plot_reest, coef.glmsmurf, summary.glmsmurf, glmsmurf, glmsmurf-class
1 | ## See example(glmsmurf) for examples
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.